@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
   Copyright (c) 2013 Jonathan Marten <jjm@keelhaul.me.uk>
 
   This program is free software; you can redistribute it and/or modify it
@@ -20,7 +20,7 @@
 
 #include "attributes/expirecollectionattribute.h"
 #include "folder/folderrequester.h"
-#include "folder/foldercollection.h"
+#include "folder/foldersettings.h"
 #include "util/mailutil.h"
 #include "kernel/mailkernel.h"
 #include "mailcommon_debug.h"
@@ -53,8 +53,8 @@ CollectionExpiryPage::~CollectionExpiryPage()
 
 bool CollectionExpiryPage::canHandle(const Akonadi::Collection &col) const
 {
-    QSharedPointer<FolderCollection> fd = FolderCollection::forCollection(col, false);
-    return (fd->canDeleteMessages() && !fd->isStructural());
+    QSharedPointer<FolderSettings> fd = FolderSettings::forCollection(col, false);
+    return fd->canDeleteMessages() && !fd->isStructural();
 }
 
 void CollectionExpiryPage::init()
@@ -73,7 +73,7 @@ void CollectionExpiryPage::init()
     expireReadMailSB->setValue(30);
     expireReadMailSB->setSuffix(ki18ncp("Expire messages after %1", " day", " days"));
     daysBox->addWidget(expireReadMailSB, 0, 1);
-    connect(expireReadMailSB, static_cast<void (KPluralHandlingSpinBox::*)(int)>(&KPluralHandlingSpinBox::valueChanged), this, &CollectionExpiryPage::slotChanged);
+    connect(expireReadMailSB, QOverload<int>::of(&KPluralHandlingSpinBox::valueChanged), this, &CollectionExpiryPage::slotChanged);
 
     expireUnreadMailCB = new QCheckBox;
     expireUnreadMailCB->setText(i18n("Expire unread messages after"));
@@ -85,7 +85,7 @@ void CollectionExpiryPage::init()
     expireUnreadMailSB->setValue(30);
     expireUnreadMailSB->setSuffix(ki18ncp("Expire messages after %1", " day", " days"));
     daysBox->addWidget(expireUnreadMailSB, 1, 1);
-    connect(expireUnreadMailSB, static_cast<void (KPluralHandlingSpinBox::*)(int)>(&KPluralHandlingSpinBox::valueChanged), this, &CollectionExpiryPage::slotChanged);
+    connect(expireUnreadMailSB, QOverload<int>::of(&KPluralHandlingSpinBox::valueChanged), this, &CollectionExpiryPage::slotChanged);
 
     daysBox->setColumnStretch(3, 1);
     globalVBox->addLayout(daysBox);
@@ -93,7 +93,7 @@ void CollectionExpiryPage::init()
     globalVBox->addSpacing(30);
 
     QGroupBox *actionsGroup = new QGroupBox;
-    actionsGroup->hide(); // for mutual exclusion of the radio buttons
+    actionsGroup->setFlat(true); // for mutual exclusion of the radio buttons
 
     QHBoxLayout *moveToHBox = new QHBoxLayout();
     moveToHBox->setMargin(0);
@@ -140,14 +140,14 @@ void CollectionExpiryPage::load(const Akonadi::Collection &collection)
     attr->daysToExpire(daysToExpireUnread, daysToExpireRead);
 
     if (expiryGloballyOn
-            && attr->readExpireUnits() != ExpireCollectionAttribute::ExpireNever
-            && daysToExpireRead >= 0) {
+        && attr->readExpireUnits() != ExpireCollectionAttribute::ExpireNever
+        && daysToExpireRead >= 0) {
         expireReadMailCB->setChecked(true);
         expireReadMailSB->setValue(daysToExpireRead);
     }
     if (expiryGloballyOn
-            && attr->unreadExpireUnits() != ExpireCollectionAttribute::ExpireNever
-            && daysToExpireUnread >= 0) {
+        && attr->unreadExpireUnits() != ExpireCollectionAttribute::ExpireNever
+        && daysToExpireUnread >= 0) {
         expireUnreadMailCB->setChecked(true);
         expireUnreadMailSB->setValue(daysToExpireUnread);
     }
@@ -192,7 +192,7 @@ void CollectionExpiryPage::saveAndExpire(Akonadi::Collection &collection, bool s
         expireNow = false;                                // settings are not valid
     }
 
-    MailCommon::ExpireCollectionAttribute *attribute = 0;
+    MailCommon::ExpireCollectionAttribute *attribute = nullptr;
     if (expireToFolder.isValid() && moveToRB->isChecked()) {
         if (expireToFolder.id() == collection.id()) {
             KMessageBox::error(this, i18n("Please select a different folder than the current folder to expire messages into.\nIf this is not done, expired messages will be permanently deleted."),
@@ -205,17 +205,17 @@ void CollectionExpiryPage::saveAndExpire(Akonadi::Collection &collection, bool s
         }
     }
     if (!attribute) {
-        attribute =  collection.attribute<MailCommon::ExpireCollectionAttribute>(Akonadi::Collection::AddIfMissing);
+        attribute = collection.attribute<MailCommon::ExpireCollectionAttribute>(Akonadi::Collection::AddIfMissing);
     }
 
     attribute->setAutoExpire(enableGlobally);
     // we always write out days now
     attribute->setReadExpireAge(expireReadMailSB->value());
     attribute->setUnreadExpireAge(expireUnreadMailSB->value());
-    attribute->setReadExpireUnits(expireReadMailCB->isChecked() ? MailCommon::ExpireCollectionAttribute::ExpireDays :
-                                  MailCommon::ExpireCollectionAttribute::ExpireNever);
-    attribute->setUnreadExpireUnits(expireUnreadMailCB->isChecked() ? MailCommon::ExpireCollectionAttribute::ExpireDays :
-                                    MailCommon::ExpireCollectionAttribute::ExpireNever);
+    attribute->setReadExpireUnits(expireReadMailCB->isChecked() ? MailCommon::ExpireCollectionAttribute::ExpireDays
+                                  : MailCommon::ExpireCollectionAttribute::ExpireNever);
+    attribute->setUnreadExpireUnits(expireUnreadMailCB->isChecked() ? MailCommon::ExpireCollectionAttribute::ExpireDays
+                                    : MailCommon::ExpireCollectionAttribute::ExpireNever);
 
     if (deletePermanentlyRB->isChecked()) {
         attribute->setExpireAction(ExpireCollectionAttribute::ExpireDelete);
@@ -271,4 +271,3 @@ void CollectionExpiryPage::slotChanged()
 {
     mChanged = true;
 }
-
