@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,13 +19,13 @@
 #include "collectiontypeutil.h"
 
 #include "incidencesforwidget.h"
-#include "contenttypewidget.h"
-#include "attributes/collectionannotationsattribute.h"
-#include "folder/foldercollection.h"
+#include <PimCommonAkonadi/ContentTypeWidget>
+#include <PimCommonAkonadi/CollectionAnnotationsAttribute>
+#include "folder/foldersettings.h"
 #include "kernel/mailkernel.h"
-#include "util/mailutil.h"
+#include "util/mailutil_p.h"
 
-#include "PimCommon/PimUtil"
+#include <PimCommon/PimUtil>
 #include <AgentManager>
 #include <AttributeFactory>
 #include <Collection>
@@ -33,11 +33,9 @@
 #include <EntityDisplayAttribute>
 #include <AkonadiCore/NewMailNotifierAttribute>
 #include <KIdentityManagement/IdentityCombo>
-#include "PimCommon/ImapResourceCapabilitiesManager"
+#include <PimCommonAkonadi/ImapResourceCapabilitiesManager>
 
 #include <KColorScheme>
-#include <KComboBox>
-#include <QDialog>
 #include <KLineEdit>
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -51,12 +49,12 @@ using namespace Akonadi;
 using namespace MailCommon;
 
 CollectionGeneralPage::CollectionGeneralPage(QWidget *parent)
-    : CollectionPropertiesPage(parent),
-      mContentsComboBox(0),
-      mIncidencesForComboBox(0),
-      mSharedSeenFlagsCheckBox(0),
-      mNameEdit(0),
-      mFolderCollection(0)
+    : CollectionPropertiesPage(parent)
+    , mContentsComboBox(nullptr)
+    , mIncidencesForComboBox(nullptr)
+    , mSharedSeenFlagsCheckBox(nullptr)
+    , mNameEdit(nullptr)
+    , mFolderCollection(nullptr)
 {
     setObjectName(QStringLiteral("MailCommon::CollectionGeneralPage"));
     setPageTitle(i18nc("@title:tab General settings for a folder.", "General"));
@@ -78,18 +76,17 @@ void CollectionGeneralPage::addLine(QWidget *parent, QVBoxLayout *layout)
 
 void CollectionGeneralPage::init(const Akonadi::Collection &collection)
 {
-    mIsLocalSystemFolder = CommonKernel->isSystemFolderCollection(collection) ||
-                           Kernel::folderIsInbox(collection, true);
+    mIsLocalSystemFolder = CommonKernel->isSystemFolderCollection(collection)
+                           || Kernel::folderIsInbox(collection);
 
     mIsResourceFolder = (collection.parentCollection() == Akonadi::Collection::root());
-    QLabel *label;
+    QLabel *label = nullptr;
 
     QVBoxLayout *topLayout = new QVBoxLayout(this);
 
     // Musn't be able to edit details for a non-resource, system folder.
-    if ((!mIsLocalSystemFolder || mIsResourceFolder) &&
-            !mFolderCollection->isReadOnly()) {
-
+    if ((!mIsLocalSystemFolder || mIsResourceFolder)
+        && !mFolderCollection->isReadOnly()) {
         QHBoxLayout *hl = new QHBoxLayout();
         topLayout->addItem(hl);
         label = new QLabel(i18nc("@label:textbox Name of the folder.", "&Name:"), this);
@@ -106,8 +103,8 @@ void CollectionGeneralPage::init(const Akonadi::Collection &collection)
     // should new mail in this folder be ignored?
     QHBoxLayout *hbl = new QHBoxLayout();
     topLayout->addItem(hbl);
-    mNotifyOnNewMailCheckBox =
-        new QCheckBox(i18n("Act on new/unread mail in this folder"), this);
+    mNotifyOnNewMailCheckBox
+        = new QCheckBox(i18n("Act on new/unread mail in this folder"), this);
     mNotifyOnNewMailCheckBox->setWhatsThis(
         i18n("<qt><p>If this option is enabled then you will be notified about "
              "new/unread mail in this folder. Moreover, going to the "
@@ -122,8 +119,8 @@ void CollectionGeneralPage::init(const Akonadi::Collection &collection)
     // should replies to mails in this folder be kept in this same folder?
     hbl = new QHBoxLayout();
     topLayout->addItem(hbl);
-    mKeepRepliesInSameFolderCheckBox =
-        new QCheckBox(i18n("Keep replies in this folder"), this);
+    mKeepRepliesInSameFolderCheckBox
+        = new QCheckBox(i18n("Keep replies in this folder"), this);
     mKeepRepliesInSameFolderCheckBox->setWhatsThis(
         i18n("Check this option if you want replies you write "
              "to mails in this folder to be put in this same folder "
@@ -133,8 +130,8 @@ void CollectionGeneralPage::init(const Akonadi::Collection &collection)
     // should this folder be shown in the folder selection dialog?
     hbl = new QHBoxLayout();
     topLayout->addItem(hbl);
-    mHideInSelectionDialogCheckBox =
-        new QCheckBox(i18n("Hide this folder in the folder selection dialog"), this);
+    mHideInSelectionDialogCheckBox
+        = new QCheckBox(i18n("Hide this folder in the folder selection dialog"), this);
     mHideInSelectionDialogCheckBox->setWhatsThis(
         xi18nc("@info:whatsthis",
                "Check this option if you do not want this folder "
@@ -173,30 +170,30 @@ void CollectionGeneralPage::init(const Akonadi::Collection &collection)
     // and it's not the personal folders (those must not be changed)
     const QString collectionResource = collection.resource();
     if (CommonKernel->imapResourceManager()->hasAnnotationSupport(collectionResource)) {
-        CollectionTypeUtil::FolderContentsType contentsType = CollectionTypeUtil::ContentsTypeMail;
+        PimCommon::CollectionTypeUtil::FolderContentsType contentsType = PimCommon::CollectionTypeUtil::ContentsTypeMail;
 
-        const CollectionAnnotationsAttribute *annotationAttribute =
-            collection.attribute<CollectionAnnotationsAttribute>();
+        const PimCommon::CollectionAnnotationsAttribute *annotationAttribute
+            = collection.attribute<PimCommon::CollectionAnnotationsAttribute>();
 
-        const QMap<QByteArray, QByteArray> annotations =
-            (annotationAttribute ?
-             annotationAttribute->annotations() :
-             QMap<QByteArray, QByteArray>());
+        const QMap<QByteArray, QByteArray> annotations
+            = (annotationAttribute
+               ? annotationAttribute->annotations()
+               : QMap<QByteArray, QByteArray>());
 
-        const bool sharedSeen = (annotations.value(CollectionTypeUtil::kolabSharedSeen()) == "true");
+        const bool sharedSeen = (annotations.value(PimCommon::CollectionTypeUtil::kolabSharedSeen()) == "true");
 
-        CollectionTypeUtil collectionUtil;
-        const CollectionTypeUtil::IncidencesFor incidencesFor =
-            collectionUtil.incidencesForFromString(QLatin1String(annotations.value(CollectionTypeUtil::kolabIncidencesFor())));
+        PimCommon::CollectionTypeUtil collectionUtil;
+        const PimCommon::CollectionTypeUtil::IncidencesFor incidencesFor
+            = collectionUtil.incidencesForFromString(QLatin1String(annotations.value(PimCommon::CollectionTypeUtil::kolabIncidencesFor())));
 
-        const CollectionTypeUtil::FolderContentsType folderType = collectionUtil.typeFromKolabName(annotations.value(CollectionTypeUtil::kolabFolderType()));
+        const PimCommon::CollectionTypeUtil::FolderContentsType folderType = collectionUtil.typeFromKolabName(annotations.value(PimCommon::CollectionTypeUtil::kolabFolderType()));
 
         ++row;
-        mContentsComboBox = new ContentTypeWidget(this);
+        mContentsComboBox = new PimCommon::ContentTypeWidget(this);
         gl->addWidget(mContentsComboBox, row, 0, 1, 2);
         mContentsComboBox->setCurrentIndex(contentsType);
 
-        connect(mContentsComboBox, &ContentTypeWidget::activated, this, &CollectionGeneralPage::slotFolderContentsSelectionChanged);
+        connect(mContentsComboBox, &PimCommon::ContentTypeWidget::activated, this, &CollectionGeneralPage::slotFolderContentsSelectionChanged);
 
         if (mFolderCollection->isReadOnly() || mIsResourceFolder) {
             mContentsComboBox->setEnabled(false);
@@ -205,9 +202,9 @@ void CollectionGeneralPage::init(const Akonadi::Collection &collection)
         // Kolab incidences-for annotation.
         // Show incidences-for combobox if the contents type can be changed (new folder),
         // or if it's set to calendar or task (existing folder)
-        const bool folderTypeComboboxEnabled = (folderType == CollectionTypeUtil::ContentsTypeCalendar || folderType == CollectionTypeUtil::ContentsTypeTask);
+        const bool folderTypeComboboxEnabled = (folderType == PimCommon::CollectionTypeUtil::ContentsTypeCalendar || folderType == PimCommon::CollectionTypeUtil::ContentsTypeTask);
         ++row;
-        mIncidencesForComboBox = new IncidencesForWidget(this);
+        mIncidencesForComboBox = new PimCommon::IncidencesForWidget(this);
         gl->addWidget(mIncidencesForComboBox, row, 0, 1, 2);
 
         mIncidencesForComboBox->setCurrentIndex(incidencesFor);
@@ -230,7 +227,7 @@ void CollectionGeneralPage::init(const Akonadi::Collection &collection)
 
 void CollectionGeneralPage::load(const Akonadi::Collection &collection)
 {
-    mFolderCollection = FolderCollection::forCollection(collection);
+    mFolderCollection = FolderSettings::forCollection(collection);
     init(collection);
 
     if (mNameEdit) {
@@ -248,23 +245,23 @@ void CollectionGeneralPage::load(const Akonadi::Collection &collection)
     // ignore new mail
     mNotifyOnNewMailCheckBox->setChecked(!Util::ignoreNewMailInFolder(collection));
 
-    const bool keepInFolder = (mFolderCollection->canCreateMessages() &&
-                               mFolderCollection->putRepliesInSameFolder());
+    const bool keepInFolder = (mFolderCollection->canCreateMessages()
+                               && mFolderCollection->putRepliesInSameFolder());
 
     mKeepRepliesInSameFolderCheckBox->setChecked(keepInFolder);
     mKeepRepliesInSameFolderCheckBox->setEnabled(mFolderCollection->canCreateMessages());
     mHideInSelectionDialogCheckBox->setChecked(mFolderCollection->hideInSelectionDialog());
 
     if (mContentsComboBox) {
-        const CollectionAnnotationsAttribute *annotationsAttribute =
-            collection.attribute<CollectionAnnotationsAttribute>();
+        const PimCommon::CollectionAnnotationsAttribute *annotationsAttribute
+            = collection.attribute<PimCommon::CollectionAnnotationsAttribute>();
 
         if (annotationsAttribute) {
             const QMap<QByteArray, QByteArray> annotations = annotationsAttribute->annotations();
-            if (annotations.contains(CollectionTypeUtil::kolabFolderType())) {
-                CollectionTypeUtil collectionUtil;
+            if (annotations.contains(PimCommon::CollectionTypeUtil::kolabFolderType())) {
+                PimCommon::CollectionTypeUtil collectionUtil;
                 mContentsComboBox->setCurrentItem(
-                    collectionUtil.typeNameFromKolabType(annotations[ CollectionTypeUtil::kolabFolderType() ]));
+                    collectionUtil.typeNameFromKolabType(annotations[ PimCommon::CollectionTypeUtil::kolabFolderType() ]));
             }
         }
     }
@@ -275,19 +272,19 @@ void CollectionGeneralPage::save(Collection &collection)
     if (mNameEdit) {
         if (!mIsLocalSystemFolder) {
             const QString nameFolder(mNameEdit->text().trimmed());
-            bool canRenameFolder =  !(nameFolder.startsWith(QLatin1Char('.')) ||
-                                      nameFolder.endsWith(QLatin1Char('.')) ||
-                                      nameFolder.contains(QLatin1Char('/')) ||
-                                      nameFolder.isEmpty());
+            bool canRenameFolder = !(nameFolder.startsWith(QLatin1Char('.'))
+                                     || nameFolder.endsWith(QLatin1Char('.'))
+                                     || nameFolder.contains(QLatin1Char('/'))
+                                     || nameFolder.isEmpty());
 
             if (mIsResourceFolder && (PimCommon::Util::isImapResource(collection.resource()))) {
                 collection.setName(nameFolder);
-                Akonadi::AgentInstance instance =
-                    Akonadi::AgentManager::self()->instance(collection.resource());
+                Akonadi::AgentInstance instance
+                    = Akonadi::AgentManager::self()->instance(collection.resource());
                 instance.setName(nameFolder);
             } else if (canRenameFolder) {
-                if (collection.hasAttribute<Akonadi::EntityDisplayAttribute>() &&
-                        !collection.attribute<Akonadi::EntityDisplayAttribute>()->displayName().isEmpty()) {
+                if (collection.hasAttribute<Akonadi::EntityDisplayAttribute>()
+                    && !collection.attribute<Akonadi::EntityDisplayAttribute>()->displayName().isEmpty()) {
                     collection.attribute<Akonadi::EntityDisplayAttribute>()->setDisplayName(
                         nameFolder);
                 } else if (!nameFolder.isEmpty()) {
@@ -304,37 +301,37 @@ void CollectionGeneralPage::save(Collection &collection)
         collection.removeAttribute<Akonadi::NewMailNotifierAttribute>();
     }
 
-    CollectionAnnotationsAttribute *annotationsAttribute =
-        collection.attribute<CollectionAnnotationsAttribute>(Collection::AddIfMissing);
+    PimCommon::CollectionAnnotationsAttribute *annotationsAttribute
+        = collection.attribute<PimCommon::CollectionAnnotationsAttribute>(Collection::AddIfMissing);
 
     QMap<QByteArray, QByteArray> annotations = annotationsAttribute->annotations();
     if (mSharedSeenFlagsCheckBox && mSharedSeenFlagsCheckBox->isEnabled()) {
-        annotations[ CollectionTypeUtil::kolabSharedSeen() ] = mSharedSeenFlagsCheckBox->isChecked() ? "true" : "false";
+        annotations[ PimCommon::CollectionTypeUtil::kolabSharedSeen() ] = mSharedSeenFlagsCheckBox->isChecked() ? "true" : "false";
     }
 
-    CollectionTypeUtil collectionUtil;
+    PimCommon::CollectionTypeUtil collectionUtil;
     if (mIncidencesForComboBox && mIncidencesForComboBox->isEnabled()) {
-        annotations[ CollectionTypeUtil::kolabIncidencesFor() ] =
-            collectionUtil.incidencesForToString(
-                static_cast<CollectionTypeUtil::IncidencesFor>(mIncidencesForComboBox->currentIndex())).toLatin1();
+        annotations[ PimCommon::CollectionTypeUtil::kolabIncidencesFor() ]
+            = collectionUtil.incidencesForToString(
+            static_cast<PimCommon::CollectionTypeUtil::IncidencesFor>(mIncidencesForComboBox->currentIndex())).toLatin1();
     }
 
     if (mContentsComboBox) {
-        const CollectionTypeUtil::FolderContentsType type =
-            collectionUtil.contentsTypeFromString(mContentsComboBox->currentText());
+        const PimCommon::CollectionTypeUtil::FolderContentsType type
+            = collectionUtil.contentsTypeFromString(mContentsComboBox->currentText());
 
         const QByteArray kolabName = collectionUtil.kolabNameFromType(type);
         if (!kolabName.isEmpty()) {
             const QString iconName = collectionUtil.iconNameFromContentsType(type);
-            Akonadi::EntityDisplayAttribute *attribute =
-                collection.attribute<Akonadi::EntityDisplayAttribute>(Akonadi::Collection::AddIfMissing);
+            Akonadi::EntityDisplayAttribute *attribute
+                = collection.attribute<Akonadi::EntityDisplayAttribute>(Akonadi::Collection::AddIfMissing);
             attribute->setIconName(iconName);
             new Akonadi::CollectionModifyJob(collection);
-            annotations[ CollectionTypeUtil::kolabFolderType() ] = kolabName;
+            annotations[ PimCommon::CollectionTypeUtil::kolabFolderType() ] = kolabName;
         }
     }
     if (annotations.isEmpty()) {
-        collection.removeAttribute<CollectionAnnotationsAttribute>();
+        collection.removeAttribute<PimCommon::CollectionAnnotationsAttribute>();
     } else {
         annotationsAttribute->setAnnotations(annotations);
     }
@@ -359,21 +356,21 @@ void CollectionGeneralPage::slotIdentityCheckboxChanged()
 
 void CollectionGeneralPage::slotFolderContentsSelectionChanged(int)
 {
-    CollectionTypeUtil collectionUtil;
-    const CollectionTypeUtil::FolderContentsType type =
-        collectionUtil.contentsTypeFromString(mContentsComboBox->currentText());
+    PimCommon::CollectionTypeUtil collectionUtil;
+    const PimCommon::CollectionTypeUtil::FolderContentsType type
+        = collectionUtil.contentsTypeFromString(mContentsComboBox->currentText());
 
-    if (type != CollectionTypeUtil::ContentsTypeMail) {
-        const QString message =
-            i18n("You have configured this folder to contain groupware information. "
-                 "That means that this folder will disappear once the configuration "
-                 "dialog is closed.");
+    if (type != PimCommon::CollectionTypeUtil::ContentsTypeMail) {
+        const QString message
+            = i18n("You have configured this folder to contain groupware information. "
+                   "That means that this folder will disappear once the configuration "
+                   "dialog is closed.");
 
         KMessageBox::information(this, message);
     }
 
-    const bool enable = (type == CollectionTypeUtil::ContentsTypeCalendar ||
-                         type == CollectionTypeUtil::ContentsTypeTask);
+    const bool enable = (type == PimCommon::CollectionTypeUtil::ContentsTypeCalendar
+                         || type == PimCommon::CollectionTypeUtil::ContentsTypeTask);
 
     if (mIncidencesForComboBox) {
         mIncidencesForComboBox->setEnabled(enable);
@@ -384,10 +381,10 @@ void CollectionGeneralPage::slotNameChanged(const QString &name)
 {
 #ifndef QT_NO_STYLE_STYLESHEET
     QString styleSheet;
-    if (name.startsWith(QLatin1Char('.')) ||
-            name.endsWith(QLatin1Char('.')) ||
-            name.contains(QLatin1Char('/')) ||
-            name.isEmpty()) {
+    if (name.startsWith(QLatin1Char('.'))
+        || name.endsWith(QLatin1Char('.'))
+        || name.contains(QLatin1Char('/'))
+        || name.trimmed().isEmpty()) {
         if (mColorName.isEmpty()) {
             const KColorScheme::BackgroundRole bgColorScheme(KColorScheme::NegativeBackground);
             KStatefulBrush bgBrush(KColorScheme::View, bgColorScheme);
@@ -399,4 +396,3 @@ void CollectionGeneralPage::slotNameChanged(const QString &name)
     setStyleSheet(styleSheet);
 #endif
 }
-
