@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,10 +19,9 @@
 #define INVALIDFILTERINFO_H
 
 #include <QString>
-#include "mailcommon_export.h"
-namespace MailCommon
-{
-class MAILCOMMON_EXPORT InvalidFilterInfo
+#include "mailcommon_private_export.h"
+namespace MailCommon {
+class MAILCOMMON_TESTS_EXPORT InvalidFilterInfo
 {
 public:
     InvalidFilterInfo();
