@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,16 +20,14 @@
 
 #include <QListView>
 #include "invalidfilterinfo.h"
-#include "mailcommon_export.h"
+#include "mailcommon_private_export.h"
 
-namespace MailCommon
-{
-
-class MAILCOMMON_EXPORT InvalidFilterListView : public QListView
+namespace MailCommon {
+class MAILCOMMON_TESTS_EXPORT InvalidFilterListView : public QListView
 {
     Q_OBJECT
 public:
-    explicit InvalidFilterListView(QWidget *parent = Q_NULLPTR);
+    explicit InvalidFilterListView(QWidget *parent = nullptr);
     ~InvalidFilterListView();
     void setInvalidFilters(const QVector<MailCommon::InvalidFilterInfo> &lst);
 Q_SIGNALS:
